==> carbon-components-react-0.1.8.tgz: package/lib/components/Accordion/Accordion-story.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _addonActions = require("@storybook/addon-actions");

var _addonKnobs = require("@storybook/addon-knobs");

var _Accordion = _interopRequireWildcard(require("../Accordion"));

var _Select = _interopRequireDefault(require("../Select"));

var _SelectItem = _interopRequireDefault(require("../SelectItem"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var props = {
  onClick: (0, _addonActions.action)('onClick'),
  onHeadingClick: (0, _addonActions.action)('onHeadingClick')
};
_Select.default.displayName = 'Select';
(0, _react2.storiesOf)('Accordion', module).addDecorator(_addonKnobs.withKnobs).add('Default', function () {
  return _react.default.createElement(_Accordion.default, null, _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: (0, _addonKnobs.text)('The title (title)', 'Section 1 title'),
    open: (0, _addonKnobs.boolean)('Open the section (open)', false)
  }, props), _react.default.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.")), _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: "Section 2 title"
  }, props), _react.default.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.")), _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: "Section 3 title"
  }, props), _react.default.createElement(_Select.default, {
    onChange: (0, _addonActions.action)('onChange'),
    id: "select-1",
    defaultValue: "placeholder-item"
  }, _react.default.createElement(_SelectItem.default, {
    disabled: true,
    hidden: true,
    value: "placeholder-item",
    text: "Choose an option"
  }), _react.default.createElement(_SelectItem.default, {
    value: "option-1",
    text: "Option 1"
  }), _react.default.createElement(_SelectItem.default, {
    value: "option-2",
    text: "Option 2"
  }), _react.default.createElement(_SelectItem.default, {
    value: "option-3",
    text: "Option 3"
  }))), _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: _react.default.createElement("span", null, "Section 4 title (", _react.default.createElement("em", null, "the title can be a node"), ")")
  }, props), _react.default.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.")));
}, {
  info: {
    text: "\n          Accordions allow users to expand and collapse sections of content.\n        "
  }
}).add('skeleton', function () {
  return _react.default.createElement("div", {
    style: {
      width: '500px'
    }
  }, _react.default.createElement(_Accordion.AccordionSkeleton, {
    open: (0, _addonKnobs.boolean)('Show first item opened (open)', true),
    count: (0, _addonKnobs.number)('Set number of items (count)', 4)
  }));
}, {
  info: {
    text: "\n          Accordions allow users to expand and collapse sections of content.\n        "
  }
});

==> carbon-components-react-0.2.8.tgz: package/lib/components/Accordion/Accordion-story.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _addonActions = require("@storybook/addon-actions");

var _addonKnobs = require("@storybook/addon-knobs");

var _Accordion = _interopRequireWildcard(require("../Accordion"));

var _Button = _interopRequireDefault(require("../Button"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var props = {
  onClick: (0, _addonActions.action)('onClick'),
  onHeadingClick: (0, _addonActions.action)('onHeadingClick')
};
(0, _react2.storiesOf)('Accordion', module).addDecorator(_addonKnobs.withKnobs).add('Default', function () {
  return _react.default.createElement(_Accordion.default, null, _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: (0, _addonKnobs.text)('The title (title)', 'Section 1 title'),
    open: (0, _addonKnobs.boolean)('Open the section (open)', false)
  }, props), _react.default.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.")), _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: "Section 2 title"
  }, props), _react.default.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.")), _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: "Section 3 title"
  }, props), _react.default.createElement(_Button.default, null, "This is a button.")), _react.default.createElement(_Accordion.AccordionItem, _extends({
    title: _react.default.createElement("span", null, "Section 4 title (", _react.default.createElement("em", null, "the title can be a node"), ")")
  }, props), _react.default.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.")));
}, {
  info: {
    text: "\n          Accordions allow users to expand and collapse sections of content.\n        "
  }
}).add('skeleton', function () {
  return _react.default.createElement("div", {
    style: {
      width: '500px'
    }
  }, _react.default.createElement(_Accordion.AccordionSkeleton, {
    open: (0, _addonKnobs.boolean)('Show first item opened (open)', true),
    count: (0, _addonKnobs.number)('Set number of items (count)', 4)
  }));
}, {
  info: {
    text: "\n          Accordions allow users to expand and collapse sections of content.\n        "
  }
});
